==> chaosmesh-model-6.3.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/PodHttpChaosPatchActionsFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface PodHttpChaosPatchActionsFluent<A extends PodHttpChaosPatchActionsFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildBody instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodHttpChaosPatchBodyAction getBody();
  public PodHttpChaosPatchBodyAction buildBody();
  public A withBody(PodHttpChaosPatchBodyAction body);
  public Boolean hasBody();
  public A withNewBody(String type,String value);
  public PodHttpChaosPatchActionsFluent.BodyNested<A> withNewBody();
  public PodHttpChaosPatchActionsFluent.BodyNested<A> withNewBodyLike(PodHttpChaosPatchBodyAction item);
  public PodHttpChaosPatchActionsFluent.BodyNested<A> editBody();
  public PodHttpChaosPatchActionsFluent.BodyNested<A> editOrNewBody();
  public PodHttpChaosPatchActionsFluent.BodyNested<A> editOrNewBodyLike(PodHttpChaosPatchBodyAction item);
  public A addToHeaders(Integer index,List<String> item);
  public A setToHeaders(Integer index,List<String> item);
  public A addToHeaders(List<String>... items);
  public A addAllToHeaders(Collection<List<String>> items);
  public A removeFromHeaders(List<String>... items);
  public A removeAllFromHeaders(Collection<List<String>> items);
  public List<List<String>> getHeaders();
  public List<String> getHeader(Integer index);
  public List<String> getFirstHeader();
  public List<String> getLastHeader();
  public List<String> getMatchingHeader(Predicate<List<String>> predicate);
  public Boolean hasMatchingHeader(Predicate<List<String>> predicate);
  public <E>A withHeaders(List<List<String>> headers);
  public A withHeaders(List<String>... headers);
  public Boolean hasHeaders();
  public A addToQueries(Integer index,List<String> item);
  public A setToQueries(Integer index,List<String> item);
  public A addToQueries(List<String>... items);
  public A addAllToQueries(Collection<List<String>> items);
  public A removeFromQueries(List<String>... items);
  public A removeAllFromQueries(Collection<List<String>> items);
  public List<List<String>> getQueries();
  public List<String> getQuery(Integer index);
  public List<String> getFirstQuery();
  public List<String> getLastQuery();
  public List<String> getMatchingQuery(Predicate<List<String>> predicate);
  public Boolean hasMatchingQuery(Predicate<List<String>> predicate);
  public <E>A withQueries(List<List<String>> queries);
  public A withQueries(List<String>... queries);
  public Boolean hasQueries();
  public interface BodyNested<N> extends Nested<N>,PodHttpChaosPatchBodyActionFluent<PodHttpChaosPatchActionsFluent.BodyNested<N>>{
    public N and();
    public N endBody();
    
  }
  
}

==> chaosmesh-model-6.7.2-sources.jar: io/fabric8/chaosmesh/v1alpha1/PodHttpChaosPatchActionsFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface PodHttpChaosPatchActionsFluent<A extends PodHttpChaosPatchActionsFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildBody instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodHttpChaosPatchBodyAction getBody();
  public PodHttpChaosPatchBodyAction buildBody();
  public A withBody(PodHttpChaosPatchBodyAction body);
  public Boolean hasBody();
  public A withNewBody(String type,String value);
  public PodHttpChaosPatchActionsFluent.BodyNested<A> withNewBody();
  public PodHttpChaosPatchActionsFluent.BodyNested<A> withNewBodyLike(PodHttpChaosPatchBodyAction item);
  public PodHttpChaosPatchActionsFluent.BodyNested<A> editBody();
  public PodHttpChaosPatchActionsFluent.BodyNested<A> editOrNewBody();
  public PodHttpChaosPatchActionsFluent.BodyNested<A> editOrNewBodyLike(PodHttpChaosPatchBodyAction item);
  public A addToHeaders(int index,List<String> item);
  public A setToHeaders(int index,List<String> item);
  public A addToHeaders(List<String>... items);
  public A addAllToHeaders(Collection<List<String>> items);
  public A removeFromHeaders(List<String>... items);
  public A removeAllFromHeaders(Collection<List<String>> items);
  public List<List<String>> getHeaders();
  public List<String> getHeader(int index);
  public List<String> getFirstHeader();
  public List<String> getLastHeader();
  public List<String> getMatchingHeader(Predicate<List<String>> predicate);
  public Boolean hasMatchingHeader(Predicate<List<String>> predicate);
  public <E>A withHeaders(List<List<String>> headers);
  public A withHeaders(List<String>... headers);
  public Boolean hasHeaders();
  public A addToQueries(int index,List<String> item);
  public A setToQueries(int index,List<String> item);
  public A addToQueries(List<String>... items);
  public A addAllToQueries(Collection<List<String>> items);
  public A removeFromQueries(List<String>... items);
  public A removeAllFromQueries(Collection<List<String>> items);
  public List<List<String>> getQueries();
  public List<String> getQuery(int index);
  public List<String> getFirstQuery();
  public List<String> getLastQuery();
  public List<String> getMatchingQuery(Predicate<List<String>> predicate);
  public Boolean hasMatchingQuery(Predicate<List<String>> predicate);
  public <E>A withQueries(List<List<String>> queries);
  public A withQueries(List<String>... queries);
  public Boolean hasQueries();
  public interface BodyNested<N> extends Nested<N>,PodHttpChaosPatchBodyActionFluent<PodHttpChaosPatchActionsFluent.BodyNested<N>>{
    public N and();
    public N endBody();
    
  }
  
}
